#from distutils.core import setup
from setuptools import setup

with open("README.md") as f:
  long_description = f.read()

setup(
  name = 'pondslider',
  packages = ['pondslider'], # this must be the same as the name above
  version = '0.5.1',
  description = 'Multipurpose sensor handler, read sensor & do somethings (send, save, trigger, ...) with the value.',
  long_description=long_description,
  long_description_content_type="text/markdown",
  author = 'Takeyuki UEDA',
  author_email = 'gde00107@nifty.com',
  license='MIT',
  url = 'https://github.com/UedaTakeyuki/pondslider', # use the URL to the github repo
  keywords = ['sensor', 'IoT'], # arbitrary keywords
  classifiers = ['Development Status :: 4 - Beta',
                 'Programming Language :: Python',
                 'Topic :: Terminals'
  ],
  install_requires=[
    "pytoml"
  ]
)



import os
import sys
import argparse
import time
import datetime
import pondslider.__init__ as pondslider

parser = argparse.ArgumentParser()
parser.add_argument("--config",
                    default=os.getcwd()+'/config.toml',
                    help="config file for handler specification.")
parser.add_argument("--version",
                    action='store_true',
                    help="show version.")
parser.add_argument("--imppaths",
										type=str, nargs='+',
                    help='list of full path for python modules import path like as "/home/pi/mh-z19 /tmp/handler" .')
parser.add_argument("--interval",
                    type=int,
                    help='minute of interval to repeat. no repeat in case not set." .')
parser.add_argument("--sensor_handlers",
                    type=str, nargs='+',
                    help='list of sensor handler modules as "sensor.mh-z19 dht22" .')
parser.add_argument("--value_handlers",
                    type=str, nargs='+',
                    help='list of value handler modules as "sender.monitor.send saver.strage.save" .')

args = parser.parse_args()

usage = 'Usage: python {} [config_file_path]'.format(__file__)

# version
if args.version:
  print ("version: ",pondslider.version)

# config file
'''
if args.config:
	configfilepath = args.config
else:
  configfilepath = os.getcwd()+'/config.toml'
'''

# additional import path
'''
if args.imppath:
	sys.path.append(args.imppath)
'''
if args.imppaths:
  for imppath in args.imppaths:
    sys.path.append(imppath)

'''
if len(sys.argv) > 1:
  configfilepath = sys.argv[1]
else:
  configfilepath = os.getcwd()+'/config.toml'
'''

if args.interval:
  while True:
    now = datetime.datetime.now()
    pondslider.read(args.config)
    pondslider.read2(args.sensor_handlers, args.value_handlers)
    now_after=datetime.datetime.now()
    elapsed=(now_after - now).seconds +  float((now_after - now).microseconds)/1000000
    if (elapsed < args.interval * 60):
        time.sleep(args.interval * 60 - elapsed)
else:
  pondslider.read(args.config)
  pondslider.read2(args.sensor_handlers, args.value_handlers)



# coding:utf-8 Copy Right Takeyuki UEDA © 2015 -
#
import os
import sys
#import inspect
import traceback
#import subprocess
#import datetime
import importlib
#import logging
#import ConfigParser
import pytoml as toml

# Const
#reboot = 'sudo reboot'

version = "0.5.1"

def error_report():
  info=sys.exc_info()
  print (traceback.format_exc(info[0]))

def read(configfilepath):
  if os.path.exists(configfilepath):
    with open(configfilepath, 'rb') as fin:
      config = toml.load(fin)

    for sensor in config["sensors"]:
      # road sensor_handler.
      sensor_handler = importlib.import_module(sensor["handler"])
      try:
        red_values = sensor_handler.read()
        print(red_values)
      except:
        error_report()
        continue

      if sensor["values"] is not None:
        values = sensor["values"]
        for value in values:
          print(value["name"])
          if value["name"] in red_values.keys():
            for handler in value["handlers"]:
              try:
                value_handler = importlib.import_module(handler)
                value_handler.handle(sensor_handler, value["name"], red_values[value["name"]])
              except:
                error_report()
                continue

def read2(sensor_handlers, value_handlers):
  if not sensor_handlers is None:
    for s in sensor_handlers:
      # road sensor_handler.
      sensor_handler = importlib.import_module(s)
      try:
        red_values = sensor_handler.read()
        print(red_values)
      except:
        error_report()
        continue

      for name, value in red_values.items():
        if not value_handlers is None:
          for v in value_handlers:
            try:
              value_handler = importlib.import_module(v)
              value_handler.handle(sensor_handler, name, value)
            except:
              error_report()
              continue
